Package: presize
Type: Package
Title: Precision Based Sample Size Calculation
Version: 0.3.11
Authors@R: 
    c(person(given = "Armando",
    family = "Lenz",
    role = "aut"),
    person(given = "Alan G.",
    family = "Haynes",
    role = c("cre", "aut"),
    email = "alan.haynes@unibe.ch"),
    person(given = "Andreas",
    family = "Limacher",
    role = "aut",
    email = "andreas.limacher@paraplegie.ch"),
    person(given = "Odile",
    family = "Stalder",
    role = "ctb",
    email = "odile.stalder@unibe.ch"),
    person(given = "Marie",
    family = "Roumet",
    role = "ctb",
    email = "marie.roumet@unibe.ch"))
Maintainer: Alan G. Haynes <alan.haynes@unibe.ch>
Description: Bland (2009) <doi:10.1136/bmj.b3985> recommended to
    base study sizes on the width of the confidence interval rather the power of 
    a statistical test. The goal of 'presize' is to provide functions for such 
    precision based sample size calculations. For a given sample size, the 
    functions will return the precision (width of the confidence interval), and 
    vice versa. 
License: GPL-3
URL: https://github.com/dcr-unibe-ch/presize,
        https://dcr-unibe-ch.github.io/presize/
BugReports: https://github.com/dcr-unibe-ch/presize/issues
Encoding: UTF-8
RoxygenNote: 7.3.3
Suggests: binom, dplyr, ggplot2, gt, Hmisc, knitr, magrittr, markdown,
        rmarkdown, shinydashboard, shinytest, testthat, tidyr
Imports: kappaSize (>= 1.2), shiny
VignetteBuilder: knitr
NeedsCompilation: no
Packaged: 2026-03-11 07:09:59 UTC; haynes
Author: Armando Lenz [aut],
  Alan G. Haynes [cre, aut],
  Andreas Limacher [aut],
  Odile Stalder [ctb],
  Marie Roumet [ctb]
Repository: CRAN
Date/Publication: 2026-03-11 08:50:02 UTC
Built: R 4.6.0; ; 2026-04-26 14:33:53 UTC; unix
