# Generated by roxygen2: do not edit by hand

S3method(as.data.frame,presize)
S3method(as.matrix,presize)
S3method(print,presize)
export(launch_presize_app)
export(prec_auc)
export(prec_cor)
export(prec_cronb)
export(prec_icc)
export(prec_kappa)
export(prec_lim_agree)
export(prec_lr)
export(prec_mean)
export(prec_meandiff)
export(prec_neg_lr)
export(prec_or)
export(prec_pos_lr)
export(prec_prop)
export(prec_rate)
export(prec_rateratio)
export(prec_riskdiff)
export(prec_riskratio)
export(prec_sens)
export(prec_spec)
import(kappaSize)
importFrom(stats,qchisq)
importFrom(stats,qnorm)
importFrom(stats,qt)
importFrom(stats,uniroot)
importFrom(utils,head)
